@@ -1,5 +1,3 @@
-context("lattice")
-
 skip_if_not_installed("lattice")
 library(lattice)
 library(stats)
@@ -78,7 +76,6 @@ test_that("lattice baselines", {
   expect_doppelganger("settings", show.settings())
 
 
-  thematic_on("black", "white", c("orange", "blue"))
+  thematic_local_theme(thematic_theme("black", "white", c("orange", "blue")))
   expect_doppelganger("settings2", show.settings())
 })
-
